@@ -12,6 +12,8 @@ class Command(BaseCommand):
             dir = settings.BASE_DIR
         else:
             dir = '.'
+        if not args:
+            raise CommandError('Need a controller name as an argument')
         for controller_name in args:
             generate_controller(dir, controller_name)
             self.stdout.write('Successfully initialized service "%s"' % controller_name)
